<?php
/*****************************************************************************
 * 名稱: 台灣里簡訊公用函式.
 * 版本: 1.5
 *
 * ChangeLog:
 *  - 2023-01-17 1.5: 更新憑證 CAINFO 檔.
 *  - 2018-01-12 1.4: 加入新 SSL root 憑證.
 *  - 2012/10/19 1.3: 新增 SSL ca_chain.pem 檔案, 啟用 CURL SSL 檢查憑證功能.
 *  - 2012/10/16 1.2: 修正簡訊發送無法指定時間的 bug.
 *  - 2012/10/10 1.1: 修正 CURL SSL 連線問題.
 *  - 2012/10/10 1.0: 初版釋出.
 *****************************************************************************/

class TWV_SMS_Service {
  // version
  public static function get_version()     { return "1.5"; }
  // lanugage
  public static function get_language_c()  { return "C"; }
  public static function get_language_e()  { return "E"; }
  // charset
  public static function get_charset_utf8(){ return "UTF-8"; }
  public static function get_charset_big5(){ return "BIG-5"; }
  public static function get_service_url() { return 'https://www.twv.com.tw/~ec/Snow/Merchant/MerchantSmsService.php'; }

  public static function service_invoke( $req_params ) {
    if( (! defined('TWV_SMS_MID')) || (strlen(TWV_SMS_MID) <= 0) ) return json_decode( '{"status":0,"err_msg":"TWV_SMS_MID 為空值"}' );
    if( (! defined('TWV_SMS_ACODE')) || (strlen(TWV_SMS_ACODE) <= 0) ) return json_decode( '{"status":0,"err_msg":"TWV_SMS_ACODE 為空值"}' );

    $req_params['version']  = TWV_SMS_Service::get_version();
    $req_params['mid']      = TWV_SMS_MID;
    $req_params['acode']    = TWV_SMS_ACODE;

    $ch = curl_init() ;
    //set the url, number of POST vars, POST data
    curl_setopt($ch, CURLOPT_URL, TWV_SMS_Service::get_service_url() ) ;
    curl_setopt($ch, CURLOPT_FAILONERROR, 1 );
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1 );
    curl_setopt($ch, CURLOPT_CAINFO, dirname(__FILE__).DIRECTORY_SEPARATOR.'ca_chain.pem' );
    curl_setopt($ch, CURLOPT_POST, 1 );
    curl_setopt($ch, CURLOPT_POSTFIELDS, $req_params);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1 );
    $result = curl_exec($ch);
    $err_msg = curl_errno($ch) == 0 ? null : ('CURL '.curl_errno($ch).' - '.curl_error($ch));
    curl_close($ch);

    if( $err_msg !== null ){
      return json_decode( '{"status":0,"err_msg":'.json_encode($err_msg).'}' );
    }

    return json_decode($result);
  }

  public static function send_sms( $language, $charset, $message, $receiver_list, $send_time=null ) {
    $req_params = array(
      "action"   => 'send_sms',
      "language" => $language,
      "charset"  => $charset,
      "message"  => $message,
      "send_time"=> ($send_time ? $send_time : ""),
      "mobiles"  => join(",",$receiver_list) );

    return TWV_SMS_Service::service_invoke( $req_params );
  }

  public static function inquiry_credit() {
    $req_params = array( "action" => 'credit_inquiry' );

    return TWV_SMS_Service::service_invoke( $req_params );
  }
}

